@@ -1,4 +1,4 @@
-package Email::Sender 1.300036;
+package Email::Sender 1.500;
 # ABSTRACT: a library for sending email
 
 use Moo::Role;
@@ -68,7 +68,7 @@ Email::Sender - a library for sending email
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 SYNOPSIS
 
@@ -108,6 +108,16 @@ classes.
 Documentation may be found in L<Email::Sender::Manual>, and new users should
 start with L<Email::Sender::Manual::QuickStart>.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 IMPLEMENTING
 
 Email::Sender itself is a Moo role.  Any class that implements Email::Sender
