@@ -1,4 +1,4 @@
-package Email::Sender::Failure::Multi 1.300036;
+package Email::Sender::Failure::Multi 1.500;
 # ABSTRACT: an aggregate of multiple failures
 
 use Moo;
@@ -84,13 +84,23 @@ Email::Sender::Failure::Multi - an aggregate of multiple failures
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
 A multiple failure report is raised when more than one failure is encountered
 when sending a single message, or when mixed states were encountered.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 failures
