@@ -1,6 +1,6 @@
 use strict;
 use warnings;
-package Email::Sender::Manual::QuickStart 1.300036;
+package Email::Sender::Manual::QuickStart 1.500;
 # ABSTRACT: how to start using Email::Sender right now
 
 #pod =head1 QUICK START
@@ -251,7 +251,17 @@ Email::Sender::Manual::QuickStart - how to start using Email::Sender right now
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
+
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 QUICK START
 
