@@ -1,4 +1,4 @@
-package Email::Sender::Role::CommonSending 1.300036;
+package Email::Sender::Role::CommonSending 1.500;
 # ABSTRACT: the common sending tasks most Email::Sender classes will need
 
 use Moo::Role;
@@ -127,7 +127,7 @@ Email::Sender::Role::CommonSending - the common sending tasks most Email::Sender
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
@@ -148,6 +148,16 @@ consult the source.
 The methods documented here may be overridden to alter the behavior of the
 CommonSending role.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 prepare_email
