@@ -1,4 +1,4 @@
-package Email::Sender::Role::HasMessage 1.300036;
+package Email::Sender::Role::HasMessage 1.500;
 # ABSTRACT: an object that has a message
 
 use Moo::Role;
@@ -29,7 +29,17 @@ Email::Sender::Role::HasMessage - an object that has a message
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
+
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 ATTRIBUTES
 
