@@ -1,4 +1,4 @@
-package Email::Sender::Success 1.300036;
+package Email::Sender::Success 1.500;
 # ABSTRACT: the result of successfully sending mail
 
 use Moo;
@@ -25,13 +25,23 @@ Email::Sender::Success - the result of successfully sending mail
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
 An Email::Sender::Success object is just an indicator that an email message was
 successfully sent.  Unless extended, it has no properties of its own.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
