@@ -1,4 +1,4 @@
-package Email::Sender::Success::Partial 1.300036;
+package Email::Sender::Success::Partial 1.500;
 # ABSTRACT: a report of partial success when delivering
 
 use Moo;
@@ -37,7 +37,7 @@ Email::Sender::Success::Partial - a report of partial success when delivering
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
@@ -45,6 +45,16 @@ These objects indicate that some delivery was accepted for some recipients and
 not others.  The success object's C<failure> attribute will return a
 L<Email::Sender::Failure::Multi> describing which parts of the delivery failed.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
