@@ -1,4 +1,4 @@
-package Email::Sender::Transport 1.300036;
+package Email::Sender::Transport 1.500;
 # ABSTRACT: a role for email transports
 
 use Moo::Role;
@@ -52,7 +52,7 @@ Email::Sender::Transport - a role for email transports
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
@@ -62,6 +62,16 @@ L<Email::Sender::Role::CommonSending>, which it includes. The important
 difference is that Transports are often intended to be used by
 L<Email::Sender::Simple>, and they provide two methods related to that purpose.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =for Pod::Coverage is_simple allow_partial_success
 
 First, they provide an C<allow_partial_success> method which returns true or
