@@ -1,4 +1,4 @@
-package Email::Sender::Transport::DevNull 1.300036;
+package Email::Sender::Transport::DevNull 1.500;
 # ABSTRACT: happily throw away your mail
 
 use Moo;
@@ -28,13 +28,23 @@ Email::Sender::Transport::DevNull - happily throw away your mail
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
 This class implements L<Email::Sender::Transport>.  Any mail sent through a
 DevNull transport will be silently discarded.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
