@@ -1,4 +1,4 @@
-package Email::Sender::Transport::Failable 1.300036;
+package Email::Sender::Transport::Failable 1.500;
 # ABSTRACT: a wrapper to makes things fail predictably
 
 use Moo;
@@ -61,7 +61,7 @@ Email::Sender::Transport::Failable - a wrapper to makes things fail predictably
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
@@ -78,6 +78,16 @@ C<send>.
 
 If any coderef returns a true value, the value will be used to signal failure.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
