@@ -1,4 +1,4 @@
-package Email::Sender::Transport::Maildir 1.300036;
+package Email::Sender::Transport::Maildir 1.500;
 # ABSTRACT: deliver mail to a maildir on disk
 
 use Moo;
@@ -186,7 +186,7 @@ Email::Sender::Transport::Maildir - deliver mail to a maildir on disk
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
@@ -208,6 +208,16 @@ C<add_envelope_headers> constructor arguments.
 The L<Email::Sender::Success> object returned on success has a C<filename>
 method that returns the filename to which the message was delivered.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
