@@ -1,4 +1,4 @@
-package Email::Sender::Transport::Mbox 1.300036;
+package Email::Sender::Transport::Mbox 1.500;
 # ABSTRACT: deliver mail to an mbox on disk
 
 use Moo;
@@ -126,7 +126,7 @@ Email::Sender::Transport::Mbox - deliver mail to an mbox on disk
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
@@ -136,6 +136,16 @@ F<filename> argument to the constructor, and defaults to F<mbox>.
 The transport I<currently> assumes that the mbox is in F<mboxo> format, but
 this may change or be configurable in the future.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
