@@ -1,4 +1,4 @@
-package Email::Sender::Transport::Print 1.300036;
+package Email::Sender::Transport::Print 1.500;
 # ABSTRACT: print email to a filehandle (like stdout)
 
 use Moo;
@@ -53,7 +53,7 @@ Email::Sender::Transport::Print - print email to a filehandle (like stdout)
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
@@ -61,6 +61,16 @@ When this transport is handed mail, it prints it to a filehandle.  By default,
 it will print to STDOUT, but it can be given any L<IO::Handle> object to print
 to as its C<fh> attribute.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
