@@ -1,4 +1,4 @@
-package Email::Sender::Transport::SMTP 1.300036;
+package Email::Sender::Transport::SMTP 1.500;
 # ABSTRACT: send email over SMTP
 
 use Moo;
@@ -352,7 +352,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
@@ -363,6 +363,16 @@ of partial success.
 For a potentially more efficient version of this transport, see
 L<Email::Sender::Transport::SMTP::Persistent>.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 The following attributes may be passed to the constructor:
