@@ -1,4 +1,4 @@
-package Email::Sender::Transport::SMTP::Persistent 1.300036;
+package Email::Sender::Transport::SMTP::Persistent 1.500;
 # ABSTRACT: an SMTP client that stays online
 
 use Moo;
@@ -69,13 +69,23 @@ Email::Sender::Transport::SMTP::Persistent - an SMTP client that stays online
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
 The stock L<Email::Sender::Transport::SMTP> reconnects each time it sends a
 message.  This transport only reconnects when the existing connection fails.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 disconnect
