@@ -1,4 +1,4 @@
-package Email::Sender::Transport::Test 1.300036;
+package Email::Sender::Transport::Test 1.500;
 # ABSTRACT: deliver mail in memory for testing
 
 use Moo;
@@ -142,13 +142,23 @@ Email::Sender::Transport::Test - deliver mail in memory for testing
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
 This transport is meant for testing email deliveries in memory.  It will store
 a record of any delivery made so that they can be inspected afterward.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 deliveries
