@@ -1,4 +1,4 @@
-package Email::Sender::Transport::Wrapper 1.300036;
+package Email::Sender::Transport::Wrapper 1.500;
 # ABSTRACT: a mailer to wrap a mailer for mailing mail
 
 use Moo;
@@ -68,7 +68,7 @@ Email::Sender::Transport::Wrapper - a mailer to wrap a mailer for mailing mail
 
 =head1 VERSION
 
-version 1.300036
+version 1.500
 
 =head1 DESCRIPTION
 
@@ -76,6 +76,16 @@ Email::Sender::Transport::Wrapper wraps a transport, provided as the
 C<transport> argument to the constructor.  It is provided as a simple way to
 use method modifiers to create wrapping classes.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@semiotic.systems>
